######################
Changes in glymur 0.14
######################

*****************
Changes in 0.14.6
*****************

    * Fix numpy 2.5 deprecation warning

*****************
Changes in 0.14.5
*****************

    * Suppress W291 warning from doctests
    * Remove two debugging breakpoints
    * Update CI infrastructure for names
    * Update testing, deprecate python 3.11
    * Use importlib.resources instead of importlib.metadata
    * Remove custom chdir context manager
    * Use sys.version() to determine if anaconda or not on tests
    * Add libgdal-jp2openjpeg to CI
    * Remove broken azure pipelines setup

*****************
Changes in 0.14.4
*****************

    * Qualify on python 3.14
    * Add User-Agent header to powershell script for Appveyor
    * Remove remaining openjpeg<2.4 artifacts
    * Remove explicit testing of numpy 1.x

*****************
Changes in 0.14.3
*****************

    * Fix import warning

*****************
Changes in 0.14.2
*****************

    * Fix test suite for python 3.14 regular expressions
    * Remove long-since-deprecated Jp2kr.read method
    * Make Jp2kr.parse method private
    * Make glymur.lib.tiff module private
    * Add doctests into circleci config

*****************
Changes in 0.14.1
*****************

    * Fix doc builds for API
    * Add additional API examples for Jp2k, Jp2kr
    * Fix tilesize reporting
    * Refactor all of setup.cfg into pyproject.toml

*****************
Changes in 0.14.0
*****************

    * Add description of raw IFD for geojp2 UUIDs
    * Add feature to convert JPEGs to JP2
    * Remove support for python 3.10
